{% load common repo_buttons %}
<table class="table table-striped table-bordered table-hover table-condensed table-responsive">
  <thead>
    <tr>
      <th class="col-sm-4">Repo Name</th>
      <th class="col-sm-4">ID</th>
      <th class="col-sm-1">Mirrors</th>
      <th class="col-sm-1">Enabled</th>
      <th class="col-sm-1">Security</th>
      <th class="col-sm-1">Auth Required</th>
    </tr>
  </thead>
  <tbody>
    {% for repo in object_list %}
      <tr>
        <td><a href="{{ repo.get_absolute_url }}">{{ repo }}</a></td>
        <td>{% if repo.id != None %} {{ repo.id }} {% endif %}</td>
        <td class="centered">{{ repo.mirror_set.count }}</td>
        <td class="centered"><form>{% yes_no_button_repo_en repo %}</form></td>
        <td class="centered"><form>{% yes_no_button_repo_sec repo %}</form></td>
        <td class="centered">{% yes_no_img repo.auth_required %}</td>
      </tr>
    {% endfor %}
  </tbody>
</table>
