{% load common %}
<table class="table table-striped table-bordered table-hover table-condensed table-responsive">
  <thead>
    <tr>
      <th class="col-sm-3">Repo</th>
      <th class="col-sm-1">ID</th>
      <th class="col-sm-1">URL</th>
      <th class="col-sm-1">Packages</th>
      <th class="col-sm-1">Enabled</th>
      <th class="col-sm-1">Refresh</th>
      <th class="col-sm-1">Mirrorlist/Metalink</th>
      <th class="col-sm-1">Last Access OK</th>
      <th class="col-sm-2">Timestamp</th>
      <th class="col-sm-1">Checksum</th>
    </tr>
  </thead>
  <tbody>
    {% for mirror in object_list %}
      <tr>
        <td><a href="{{ mirror.repo.get_absolute_url }}">{{ mirror.repo }}</a></td>
        <td><a href="{{ mirror.get_absolute_url }}">{{ mirror.id }}</a></td>
        <td><a href="{{ mirror.url }}">{{ mirror.url|truncatechars:25 }}</a></td>
        <td class="centered">{{ mirror.packages.count }}</td>
        <td class="centered">{% yes_no_img mirror.enabled 'Enabled' 'Not Enabled' %}</td>
        <td class="centered">{% yes_no_img mirror.refresh 'Yes' 'No' %}</td>
        <td class="centered">{% yes_no_img mirror.mirrorlist 'Yes' 'No' %}</td>
        <td class="centered">{% yes_no_img mirror.last_access_ok 'Yes' 'No' %}</td>
        <td>{{ mirror.timestamp }}</td>
        <td>{{ mirror.file_checksum|truncatechars:16 }}</td>
      </tr>
    {% endfor %}
  </tbody>
</table>
