{% extends "base.html" %}

{% load common bootstrap3 static %}

{% block content %}

<div class="row">
  <div class="col-sm-10">
    {% searchform %}
    {% gen_table page.object_list %}
    <div class="centered">
      {% object_count page %}
    </div>
    <div class="centered">
      {% get_querystring request as querystring %}
      {% bootstrap_pagination page size='small' extra=querystring %}
    </div>
    <div class="centered">
      Page {{ page.number }} of {{ page.paginator.num_pages }}
    </div>
  </div>

  {% if filter_bar %}
    <div class="col-sm-2">
      <div class="panel panel-primary">
        <div class="panel-heading">Filter by...</div>
        <div class="panel-body">
        {{ filter_bar|safe }}
        </div>
      </div>
    </div>
  {% endif %}
</div>

{% block objectlist_actions %}{% endblock %}

{% endblock %}
