{% load common %}
<table class="table table-striped table-bordered table-hover table-condensed table-responsive">
  <thead>
    <tr>
      <th class="col-sm-2">ID</th>
      <th class="col-sm-3">Host</th>
      <th class="col-sm-3">Time</th>
      <th class="col-sm-3">IP Address</th>
      <th class="col-sm-1">Processed</th>
    </tr>
  </thead>
  <tbody>
    {% for report in object_list %}
      <tr>
        <td><a href="{{ report.get_absolute_url }}"> {{ report.id }} </a></td>
        <td> {{ report.host }} </td>
        <td> {{ report.created }} </td>
        <td> {{ report.report_ip }} </td>
        <td class="centered"> {% yes_no_img report.processed 'Processed' 'Not Processed' %}</td>
      </tr>
    {% endfor %}
  </tbody>
</table>
