{% extends "base.html" %}

{% block page_title %}404 - Page not found{% endblock %}

{% block content_title %}404 - Page not found{% endblock %}

{% block content %}
  <div class="well well-sm">
    Sorry, but the requested page could not be found.
  </div>
{% endblock %}
